FluidEntry<ValueType, DefaultValueType extends ValueType?> class abstract

Implementers

Constructors

FluidEntry({required String key, required DefaultValueType defaultValue, required bool isSecure})

Properties

defaultValue → DefaultValueType
final
hashCode int
The hash code for this object.
no setterinherited
isSecure bool
final
key String
final
prefs → FluidStorageBase
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() Future<DefaultValueType>
toString() String
A string representation of this object.
inherited
write(ValueType value) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited